@@ -1,4 +1,4 @@
-package Pcore::PDF v0.4.0;
+package Pcore::PDF v0.4.1;
 
 use Pcore -dist, -class, -const, -result;
 use Config;
@@ -38,7 +38,7 @@ const our $PAGE_SIZE => {
     Tabloid   => '279.4 x 431.8 mm',
 };
 
-has prince => ( is => 'lazy', isa => Str );
+has bin => ( is => 'lazy', isa => Str );
 has max_threads => ( is => 'ro', isa => PositiveInt, default => ( $MSWIN ? 1 : 4 ) );
 has page_size => ( is => 'ro', isa => Enum [ keys $PAGE_SIZE->%* ], default => 'A4' );
 
@@ -119,7 +119,7 @@ sub update_all ( $self, $cb = undef ) {
                         # TODO
                     }
                     else {
-                        P->file->untar( $res->body->path, $ENV->share->get_storage( 'bin/', 'Pcore-PDF' ) . "princexml-linux-generic-x64-$princexml_ver/", strip_component => 1 );
+                        P->file->untar( $res->body->path, $ENV->share->get_lib('Pcore-PDF') . "bin/princexml-linux-generic-x64-$princexml_ver/", strip_component => 1 );
                     }
 
                     1;
@@ -194,7 +194,7 @@ sub _generate_mswin ( $self ) {
     $self->{_threads}++;
 
     P->pm->run_proc(
-        [ $self->prince, '-' ],
+        [ $self->bin, '-' ],
         stdin    => 1,
         stdout   => 1,
         on_ready => sub ($proc) {
@@ -257,7 +257,7 @@ sub _get_proc ( $self, $cb ) {
     $self->{_threads}++;
 
     P->pm->run_proc(
-        [ $self->prince, '--control' ],
+        [ $self->bin, '--control' ],
         stdin    => 1,
         stdout   => 1,
         stderr   => 1,
@@ -444,7 +444,7 @@ Pcore::PDF - non-blocking HTML to PDF converter
     use Pcore::PDF;
 
     my $pdf = Pcore::PDF->new({
-        prince      => 'path-to-princexml-executable',
+        bin         => 'path-to-princexml-executable',
         max_threads => 4,
     });
 
@@ -472,7 +472,7 @@ Generate PDF from HTML templates, using princexml.
 
 =over
 
-=item prince
+=item bin
 
 Path to F<princexml> executable. Mandatory attribute.
 
